@@ -1,5 +1,5 @@
 /*
- * $Id: acl.c,v 1.12.2.32 1996/08/26 19:05:54 wessels Exp $
+ * $Id: acl.c,v 1.12.2.33 1996/09/12 21:39:40 wessels Exp $
  *
  * DEBUG: section 28    Access Control
  * AUTHOR: Duane Wessels
@@ -33,6 +33,9 @@
 /* These two should never be referenced directly in this file! */
 struct _acl_access *HTTPAccessList = NULL;
 struct _acl_access *ICPAccessList = NULL;
+#if DELAY_HACK
+struct _acl_access *DelayAccessList = NULL;
+#endif
 
 static struct _acl *AclList = NULL;
 static struct _acl **AclListTail = &AclList;
