@@ -1,6 +1,6 @@
 
 /*
- * $Id: ssl.c,v 1.1.2.23 1996/07/24 17:03:09 wessels Exp $
+ * $Id: ssl.c,v 1.1.2.24 1996/08/22 16:50:07 wessels Exp $
  *
  * DEBUG: section 26    Secure Sockets Layer Proxy
  * AUTHOR: Duane Wessels
@@ -85,6 +85,10 @@ static int sslClientClosed(fd, sslState)
     debug(26, 3, "sslClientClosed: FD %d\n", fd);
     /* we have been called from comm_close for the client side, so
      * just need to clean up the server side */
+    protoUndispatch(sslState->server.fd,
+	sslState->url,
+	NULL,
+	sslState->request);
     comm_close(sslState->server.fd);
     return 0;
 }
