@@ -1,5 +1,5 @@
 /*
- * $Id: store_clean.c,v 1.1.2.4 1996/08/19 19:51:12 wessels Exp $
+ * $Id: store_clean.c,v 1.1.2.7 1996/11/24 05:32:10 wessels Exp $
  *
  * DEBUG: section 36    Cache Directory Cleanup
  * AUTHOR: Duane Wessels
@@ -67,6 +67,9 @@ void storeDirClean()
     int fileno;
     int n = 0;
     int k = 0;
+#ifdef _SQUID_UNIXWARE_
+    return;
+#endif
     sprintf(p1, "%s/%02d",
 	swappath(index),
 	(index / ncache_dirs) % SWAP_DIRECTORIES);
@@ -74,7 +77,7 @@ void storeDirClean()
     dp = opendir(p1);
     if (dp == NULL) {
 	debug(36, 0, "storeDirClean: %s: %s\n", p1, xstrerror());
-	fatal_dump(NULL);
+	return;
     }
     while ((de = readdir(dp)) && k < 20) {
 	if (sscanf(de->d_name, "%d", &fileno) != 1)
